@@ -141,13 +141,13 @@ class GRPCException(Exception):
 
 
 class Unauthenticated(GRPCException):
-    status_code = StatusCode.UNAUTHENTICATED.value
+    status_code = StatusCode.UNAUTHENTICATED
     default_detail = _("Authentication credentials were not provided.")
     default_code = "not_authenticated"
 
 
 class PermissionDenied(GRPCException):
-    status_code = StatusCode.PERMISSION_DENIED.value
+    status_code = StatusCode.PERMISSION_DENIED
     default_detail = _("You do not have permission to perform this action.")
     default_code = "permission_denied"
 
